Documentation
¶
Overview ¶
Package codec provides composable JSON codecs over encoding/json/jsontext
Index ¶
Constants ¶
This section is empty.
Variables ¶
Functions ¶
func DecodeFrom ¶
DecodeFrom reads a single JSON value from r using the given codec
Types ¶
type Codec ¶
type Codec[T any] interface { Decode(*jsontext.Decoder) (T, error) Encode(*jsontext.Encoder, T) error }
Codec reads and writes a single Go value as a JSON value
type Numeric ¶
type Numeric interface {
~int | ~int8 | ~int16 | ~int32 | ~int64 |
~uint | ~uint8 | ~uint16 | ~uint32 | ~uint64 |
~float32 | ~float64
}
Numeric is any Go type whose JSON representation is a number
type StructField ¶
StructField binds one JSON object member to a field of struct S
Click to show internal directories.
Click to hide internal directories.